@@ -28,7 +28,7 @@ from manilaclient import client as manila_client
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.46"
+MANILA_VERSION = "2.50"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -88,6 +88,7 @@ def manilaclient(request):
 
 
 def share_list(request, search_opts=None):
+    search_opts = search_opts or {}
     return manilaclient(request).shares.list(search_opts=search_opts)
 
 
@@ -427,6 +428,17 @@ def share_type_create(request, name, spec_driver_handles_share_servers,
         is_public=is_public)
 
 
+def share_type_update(request, share_type_id, name=None, description=None,
+                      is_public=None):
+    share_type_data = {
+        'name': name,
+        'description': description,
+        'is_public': is_public
+    }
+    return manilaclient(request).share_types.get(
+        share_type_id).update(**share_type_data)
+
+
 def share_type_delete(request, share_type_id):
     return manilaclient(request).share_types.delete(share_type_id)
 
@@ -463,12 +475,10 @@ def share_replica_list(request, share=None):
     return manilaclient(request).share_replicas.list(share)
 
 
-def share_replica_create(request, share, availability_zone,
-                         share_network=None):
+def share_replica_create(request, share, availability_zone):
     return manilaclient(request).share_replicas.create(
         share,
-        availability_zone=availability_zone,
-        share_network=share_network)
+        availability_zone=availability_zone)
 
 
 def share_replica_get(request, replica):
